@@ -170,7 +170,7 @@ class CSVKitUtility(object):
                                 help='Whether or not double quotes are doubled in the input CSV file.')
         if 'p' not in self.override_flags:
             self.argparser.add_argument('-p', '--escapechar', dest='escapechar',
-                                help='Character used to escape the delimiter if quoting is set to "Quote None" and the quotechar if doublequote is not specified.')
+                                help='Character used to escape the delimiter if --quoting 3 ("Quote None") is specified and to escape the QUOTECHAR if --doublequote is not specified.')
         if 'z' not in self.override_flags:
             self.argparser.add_argument('-z', '--maxfieldsize', dest='maxfieldsize', type=int,
                                 help='Maximum length of a single field in the input CSV file.')
